@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2004-2020 ZNC, see the NOTICE file for details.
+ * Copyright (C) 2004-2024 ZNC, see the NOTICE file for details.
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -20,10 +20,10 @@
 #define BUILD_WITH_CMAKE 1
 
 #define VERSION_MAJOR 1
-#define VERSION_MINOR 8
-#define VERSION_PATCH 2
-#define VERSION_STR "1.8.2"
-#define VERSION_EXTRA "+cygwin5"
+#define VERSION_MINOR 9
+#define VERSION_PATCH 0
+#define VERSION_STR "1.9.0"
+#define VERSION_EXTRA "+cygwin1"
 
 /* #undef _GLIBCXX_DEBUG */
 /* #undef _GLIBCXX_DEBUG_PEDANTIC */
@@ -31,9 +31,11 @@
 #define HAVE_PTHREAD 1
 #define HAVE_THREADED_DNS 1
 #define HAVE_LIBSSL 1
+#define HAVE_SSL_SESSION_get0_cipher 1
 #define HAVE_IPV6 1
 #define HAVE_ZLIB 1
-#define HAVE_I18N 1
+/* #undef HAVE_I18N */
+#define ZNC_HAVE_ARGON 1
 #define CSOCK_USE_POLL 1
 
 #define HAVE_GETOPT_LONG 1
